#
# spec file for package fcitx5-kkc
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fcitx5-kkc
Version:        5.1.7
Release:        1.1
Summary:        Libkkc input method support for Fcitx5
License:        GPL-3.0-or-later
Group:          System/I18n/Japanese
URL:            https://github.com/fcitx/fcitx5-kkc
Source:         https://download.fcitx-im.org/fcitx5/%{name}/%{name}-%{version}.tar.zst
BuildRequires:  cmake
BuildRequires:  extra-cmake-modules
BuildRequires:  fcitx5-devel
BuildRequires:  fcitx5-qt-devel
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libkkc-devel
BuildRequires:  pkgconfig
BuildRequires:  qt6-base-devel
BuildRequires:  zstd
Requires:       fcitx5
Requires:       kkc-data
Provides:       fcitx-kkc = %{version}
Obsoletes:      fcitx-kkc <= 0.1.4
Obsoletes:      fcitx5-kkc-qt6 <= 5.1.6
Supplements:    (fcitx5 and kkc-data)
%if 0%{?suse_version} <= 1520
BuildRequires:  appstream-glib-devel
%endif

%description
This package provides libkkc input method support for Fcitx5.

%prep
%setup -q -n %{name}-%{version}

%build
%if 0%{?suse_version} == 1500
%cmake -DCMAKE_CXX_COMPILER=%{_bindir}/g++-13
%else
%cmake
%endif
%make_build

%install
%cmake_install
%find_lang %{name}

%files -f %{name}.lang
%doc README.md
%license LICENSES
%dir %{_datadir}/fcitx5/inputmethod
%dir %{_datadir}/fcitx5/kkc
%{_libdir}/fcitx5/kkc.so
%{_libdir}/fcitx5/qt6/libfcitx5-kkc-config.so
%{_datadir}/fcitx5/addon/kkc.conf
%{_datadir}/fcitx5/inputmethod/kkc.conf
%{_datadir}/fcitx5/kkc/dictionary_list
%{_datadir}/fcitx5/kkc/rule
%{_datadir}/icons/hicolor/*/apps/fcitx_kkc.png
%{_datadir}/icons/hicolor/*/apps/org.fcitx.Fcitx5.fcitx_kkc.png
%{_datadir}/metainfo/org.fcitx.Fcitx5.Addon.Kkc.metainfo.xml

%changelog
* Sun Jun 22 2025 Marguerite Su <i@marguerite.su>
- update to 5.1.7
  * get rid of fcitx::getline usage
  * port to StandardPaths
- upstream drop qt5, switch from _multibuild to single build again
* Wed Jan 29 2025 Marguerite Su <i@marguerite.su>
- update to 5.1.6
  * use addon factory v2
  * do not include keysymgen.h
* Sat Jan 11 2025 Marguerite Su <i@marguerite.su>
- fix leap 15.6 build
  * use g++-13 to workaround the <filesystem> include
* Sun Jan  5 2025 Marguerite Su <i@marguerite.su>
- update to 5.1.5
  * translation update
- changes in 5.1.4
  * Rename icons to avoid XDG icon name fallback with breeze icon theme
* Thu May 23 2024 Marguerite Su <i@marguerite.su>
- update to 5.1.3
  * Use Qt6 by default
* Mon Feb  5 2024 Marguerite Su <i@marguerite.su>
- update to 5.1.1
  * Port to Qt 6
* Sun Aug 20 2023 Marguerite Su <i@marguerite.su>
- update to 5.1.0
  * remove the unintended c++11 flag
- drop 0000-remove-cpp11.patch
* Thu May 11 2023 Xu Zhao <i@xuzhao.net>
- Use the .tar.xz source downloaded from fcitx-im.org
* Wed May 10 2023 Xu Zhao <i@xuzhao.net>
- Update to 5.0.12
  * Update translation
- Add 0000-remove-cpp11.patch
  * Remove the unintended C++11 flag
* Sun Nov 20 2022 Fusion Future <qydwhotmail@gmail.com>
- Update to 5.0.11
  * Update translation
* Tue Jul  5 2022 Fusion Future <qydwhotmail@gmail.com>
- Update to 5.0.10
  * Update translation
* Sun Mar 13 2022 Marguerite Su <i@marguerite.su>
- update version 5.0.8
  * Add missing include <array>
* Wed Dec 15 2021 Marguerite Su <i@marguerite.su>
- update version 5.0.6
* Wed May  5 2021 Marguerite Su <i@marguerite.su>
- update version 5.0.5
  * Implement sub mode label
* Tue Mar 16 2021 Marguerite Su <i@marguerite.su>
- update version 5.0.4
  * show mode information if the input mode is changed.
* Sun Jan 31 2021 Marguerite Su <i@marguerite.su>
- update version 5.0.3
  * Make label in UI more meaningful
* Sun Dec  6 2020 Marguerite Su <i@marguerite.su>
- update version 5.0.2
* Tue Nov 10 2020 Marguerite Su <i@marguerite.su>
- update version 5.0.0
* Fri Sep  4 2020 Marguerite Su <i@marguerite.su>
- update version 0.0.0+git20200803.7c6d0b5
* Tue Mar  3 2020 Xu Zhao <i@xuzhao.net>
- update to git20200303.ad7f804
  * workaround for a bug with libkkc
* Sun Sep 16 2018 i@marguerite.su
- initial package
